@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2001-2008
+ * Copyright (c) 2001, 2008,
  *     DecisionSoft Limited. All rights reserved.
- * Copyright (c) 2004-2008
- *     Oracle. All rights reserved.
+ * Copyright (c) 2004, 2018 Oracle and/or its affiliates. All rights reserved.
+ *     
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,6 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
- * $Id: FunctionCurrentDateTime.hpp 659 2008-10-06 00:11:22Z jpcs $
  */
 
 /*
@@ -30,7 +28,6 @@
 
 #include <xqilla/ast/XQFunction.hpp>
 
-/** Current-dateTime function*/
 class XQILLA_API FunctionCurrentDateTime : public XQFunction
 {
 public:
@@ -40,12 +37,11 @@ public:
 
   FunctionCurrentDateTime(const VectorOfASTNodes &args, XPath2MemoryManager* memMgr);
   
-  virtual ASTNode* staticResolution(StaticContext *context);
   virtual ASTNode *staticTypingImpl(StaticContext *context);
 
   Sequence createSequence(DynamicContext* context, int flags=0) const;
 };
 
-#endif // _FUNCTIONCURRENT_DATETIME_HPP
+#endif
 
 
